package img;

import javax.swing.*;
import java.awt.*;

/**
 * The class encapsulates a frame that is capable of displaying a
 * DigitalPicture.
 * 
 * This class is based on an original specificaion from Guzdial and Ericson,
 * with explanatory comments and modifications provided by various contributors:
 * mb@cse.yorku.ca
 */
public class PictureFrame {

	private JFrame frame = new JFrame();
	private ImageIcon imageIcon = new ImageIcon();
	private JLabel label = new JLabel(imageIcon);
	private AbstractDigitalPicture picture;

	/**
	 * Default constructor that ...
	 * 
	 * A constructor that takes no arguments. This is needed for subclasses of
	 * this class
	 */
	public PictureFrame() {
		// set up the frame
		initFrame();
	}

	/**
	 * Constructs a PictureFrame for the passed DigitalPicture object.
	 * 
	 * @param picture
	 *            the digital picture to display in the picture frame
	 */
	public PictureFrame(AbstractDigitalPicture picture) {
		// set the current object's picture to the passed in picture
		this.picture = picture;

		// set up the frame
		initFrame();
	}

	/**
	 * Set the digital picture to be shown in the this picture frame
	 * 
	 * @param picture
	 *            the digital picture to be shown in this frame
	 */
	public void setPicture(AbstractDigitalPicture picture) {
		this.picture = picture;
		imageIcon.setImage(picture.getImage());
		frame.pack();
		frame.repaint();
	}

	/**
	 * Update this picture frame to show the current digital picture (it may
	 * have been changed since the most recent display)
	 */
	public void updateImage() {
		// only do this if there is a picture
		if (picture != null) {
			// set the image for the image icon from the picture
			Image img = picture.getImage();
			imageIcon.setImage(img);

			// set the title of the frame to the title of the picture
			frame.setTitle(picture.getTitle());

		}
	}

	/**
	 * A method to update the picture frame image with the image in the picture
	 * and show it
	 */
	public void updateImageAndShowIt() {
		// first update the image
		updateImage();

		// now make sure it is shown
		frame.setVisible(true);
	}

	/**
	 * Ensure that this picture frame is shown on the current graphical display.
	 */
	public void displayImage() {
		frame.setVisible(true);
	}

	/**
	 * Ensure that this picture frame is not shown on the current graphical
	 * display.
	 */
	public void hide() {
		frame.setVisible(false);
	}

	/**
	 * Specify whether this picture frame is shown on the current graphical
	 * display or not, as per the passed boolean flag.
	 * 
	 * @param shouldBeShown
	 *            a boolean value that indicates whether this picture frame
	 *            should be shown on not.
	 */
	public void setVisible(boolean shouldBeShown) {
		frame.setVisible(shouldBeShown);
	}

	/**
	 * Causes this picture frame to be closed.
	 */
	public void close() {
		frame.setVisible(false);
		frame.dispose();
	}

	/**
	 * Set the title for the picture frame to be the passed string value.
	 * 
	 * @param title
	 *            as described above
	 */
	public void setTitle(String title) {
		frame.setTitle(title);
	}

	/**
	 * Cause this picture frame to signal to the graphics manager that it needs
	 * to be redrawn at the next opportunity.
	 */
	public void repaint() {

		// make it visible
		frame.setVisible(true);

		// update the image from the picture
		updateImage();

		// tell the JFrame to handle the repaint
		frame.repaint();
	}

	/**
	 * Causes this picture frame to be initialized.
	 */
	private void initFrame() {

		// set the image for the picture frame
		updateImage();

		// add the label to the frame
		frame.getContentPane().add(label);

		// pack the frame (set the size to as big as it needs to be)
		frame.pack();

		// make the frame visible
		frame.setVisible(true);
		frame.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
	}

}